#
# spec file for package xsimd
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xsimd
Version:        13.0.0
Release:        1.1
Summary:        C++ wrappers for SIMD intrinsics
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://xsimd.readthedocs.io/en/latest/
Source0:        https://github.com/xtensor-stack/xsimd/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  doctest-devel
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  python3-breathe
BuildRequires:  cmake(GTest)

%description
SIMD (Single Instruction, Multiple Data) is a feature of microprocessors that
has been available for many years. SIMD instructions perform a single operation
on a batch of values at once, and thus provide a way to significantly accelerate
code execution. However, these instructions differ between microprocessor
vendors and compilers.

xsimd provides a unified means for using these features for library authors.
Namely, it enables manipulation of batches of numbers with the same arithmetic
operators as for single values. It also provides accelerated implementation of
common mathematical functions operating on batches.

%prep
%autosetup -p1

%build
%cmake -DBUILD_TESTS:BOOL=ON

%cmake_build

# Build documentation
pushd %{_builddir}/%{name}-%{version}/docs
%make_build html
popd

%install
%cmake_install

#install documentation
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -r %{_builddir}/%{name}-%{version}/docs/build/html/* %{buildroot}%{_docdir}/%{name}

%check
%ctest

%package devel
Summary:        Development files for xsimd

%description devel
SIMD (Single Instruction, Multiple Data) is a feature of microprocessors that
has been available for many years. SIMD instructions perform a single operation
on a batch of values at once, and thus provide a way to significantly accelerate
code execution. However, these instructions differ between microprocessor
vendors and compilers.

xsimd provides a unified means for using these features for library authors.
Namely, it enables manipulation of batches of numbers with the same arithmetic
operators as for single values. It also provides accelerated implementation of
common mathematical functions operating on batches.

This package contains the developments files needed to use xsimd

%files devel
%license LICENSE
%{_includedir}/xsimd
%{_libdir}/cmake/xsimd
%{_libdir}/pkgconfig/xsimd.pc

%package doc
Summary:        Documentation for xsimd
Group:          Documentation/HTML

%description doc
SIMD (Single Instruction, Multiple Data) is a feature of microprocessors that
has been available for many years. SIMD instructions perform a single operation
on a batch of values at once, and thus provide a way to significantly accelerate
code execution. However, these instructions differ between microprocessor
vendors and compilers.

xsimd provides a unified means for using these features for library authors.
Namely, it enables manipulation of batches of numbers with the same arithmetic
operators as for single values. It also provides accelerated implementation of
common mathematical functions operating on batches.

This package contains the xsimd documentation

%files doc
%doc %{_docdir}/%{name}

%changelog
* Fri May 17 2024 Dirk Müller <dmueller@suse.com>
- update to 13.0.0:
  * Most xsimd functions are flagged as always_inline
  * Fix some xsimd scalar version (abs, bitofsign, signbit,
    bitwise_cast, exp10)
  * Move from batch_constant<batch<T, A>, Csts...> to
    batch_constant<T, A, Csts...>
  * Move from batch_bool_constant<batch<T, A>, Csts...> to
    batch_bool_constant<T, A, Csts...>
  * Provide an as_batch() method (resp. as_batch_bool) method for
    batch_constant (resp. batch_bool_constant)
  * New architecture emulated<N> for batches of N bits emulated
    using scalar operations.
  * Remove the version method from all architectures
  * Support xsimd::avg and xsimd::avgr vector operation
  * Model i8mm arm extension
  * Fix dispatching mechanism
* Tue Mar 12 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Move install commands into %%install section
* Sun Dec 17 2023 Dirk Müller <dmueller@suse.com>
- update to 12.1.1:
  * Update readme with a section on adoption, and a section on
    the history of the project
  * Fix/avx512vnni implementation
  * Fix regression on XSIMD_NO_SUPPORTED_ARCHITECTURE
* Sun Nov 26 2023 Dirk Müller <dmueller@suse.com>
- update to 11.2.0:
  * Provide shuffle operations of floating point batches
  * Provide a generic implementation of xsimd::swizzle with
    dynamic indices
  * Implement rotl, rotr, rotate_left and rotate_right
  * Let CMake figure out pkgconfig directories
  * Add missing boolean operators in xsimd_api.hpp
  * Initial Implementation for the new WASM based instruction set
  * Provide a generic version for float to uint32_t conversion
* Tue Jun 27 2023 Dirk Müller <dmueller@suse.com>
- update to 11.1.0:
  * Introduce XSIMD_DEFAULT_ARCH to force default architecture
    (if any)
  * Remove C++ requirement on xsimd::exp10 scalar implementation
  * Improve and test documentation
  * Provide a generic reducer
  * Fix ``find_package(xsimd)`` for xtl enabled xsimd, reloaded
  * Cleanup benchmark code
  * Provide avx512f implementation of FMA and variant
  * Hexadecimal floating points are not a C++11 feature
  * back to slow implementation of exp10 on Windows
  * Changed bitwise_cast API
  * Provide generic signed /unsigned type conversion
  * Fixed sde location
  * Feature/incr decr
  * Cleanup documentation
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to 10.0.0:
  * SVE: Implement scatter/gather
  * SVE: Implement nearbyint and ldexp
  * Use intrinsic instead of generic implementation of ldexp on avx512f
  * SVE: Implement fused operations for all types
- drop 0001-Only-use-_mm_insert_epi64-on-64-bit-architecture.patch (upstream)
* Wed Nov  9 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 9.0.1. No changelog.
- Spec cleanup. Prepare xsimd for the factory submission
- Add upstream change:
  * 0001-Only-use-_mm_insert_epi64-on-64-bit-architecture.patch
* Sun Jul 17 2022 Matwey Kornilov <matwey.kornilov@gmail.com>
- Update to version 8.1.0
* Fri Mar 26 2021 Daniel Weatherill <plasteredparrot@gmail.com>
- initial build from upstream version 7.4.9
